@@ -35,6 +35,7 @@ using namespace lime;
  * Constructor/destructor
  ******************************************************************/
 SoapyLMS7::SoapyLMS7(const ConnectionHandle &handle, const SoapySDR::Kwargs &args):
+    _deviceArgs(args),
     _conn(nullptr),
     _moduleName(handle.module)
 {
@@ -70,6 +71,17 @@ SoapyLMS7::SoapyLMS7(const ConnectionHandle &handle, const SoapySDR::Kwargs &arg
 
         st = _rfics.back()->SoftReset();
         if (st != 0) throw std::runtime_error("SoftReset() failed");
+        if (devInfo.deviceName.find("LimeSDR-mini")!=std::string::npos)
+        {
+            st = _rfics.back()->SPI_write(0xA6,0x0001);
+            if (st != 0) throw std::runtime_error("SPI_write() failed");
+            st = _rfics.back()->SPI_write(0x92,0xFFFF);
+            if (st != 0) throw std::runtime_error("SPI_write() failed");
+            st = _rfics.back()->SPI_write(0x93,0x03FF);
+            if (st != 0) throw std::runtime_error("SPI_write() failed");
+            st = _rfics.back()->SPI_write(0x8B,0x338E);
+            if (st != 0) throw std::runtime_error("SPI_write() failed");
+        }
 
         st = _rfics.back()->UploadAll();
         if (st != 0) throw std::runtime_error("UploadAll() failed");
@@ -85,7 +97,7 @@ SoapyLMS7::SoapyLMS7(const ConnectionHandle &handle, const SoapySDR::Kwargs &arg
 
     //enable use of calibration value cache automatically
     //or specify args[cacheCalibrations] == 0 to disable
-    const bool cacheEnable = args.count("cacheCalibrations") == 0 or std::stoi(args.at("cacheCalibrations")) != 0;
+    const bool cacheEnable = args.count("cacheCalibrations") and std::stoi(args.at("cacheCalibrations")) != 0;
     SoapySDR::logf(SOAPY_SDR_INFO, "LMS7002M calibration values caching %s", cacheEnable?"Enable":"Disable");
     for (auto rfic : _rfics) rfic->EnableValuesCache(cacheEnable);
 
@@ -97,12 +109,13 @@ SoapyLMS7::SoapyLMS7(const ConnectionHandle &handle, const SoapySDR::Kwargs &arg
     {
         this->setFrequency(SOAPY_SDR_RX, channel, "BB", 0.0);
         this->setFrequency(SOAPY_SDR_TX, channel, "BB", 0.0);
-        this->setAntenna(SOAPY_SDR_RX, channel, "LNAL");
+        this->setAntenna(SOAPY_SDR_RX, channel, devInfo.deviceName.find("LimeSDR-mini")!=std::string::npos ? "LNAH" :  "LNAL");
         this->setAntenna(SOAPY_SDR_TX, channel, "BAND1");
         this->setGain(SOAPY_SDR_RX, channel, "PGA", 0);
         this->setGain(SOAPY_SDR_RX, channel, "LNA", 0);
-        this->setGain(SOAPY_SDR_RX, channel, "TIA", 0);
-        this->setGain(SOAPY_SDR_TX, channel, "PAD", -50);
+        this->setGain(SOAPY_SDR_RX, channel, "TIA", 9);
+        this->setGain(SOAPY_SDR_TX, channel, "PAD", 0);
+        this->setGain(SOAPY_SDR_TX, channel, "IAMP", 0);
         this->setSampleRate(SOAPY_SDR_RX, channel, defaultClockRate/8);
         this->setSampleRate(SOAPY_SDR_TX, channel, defaultClockRate/8);
         this->setBandwidth(SOAPY_SDR_RX, channel, 30e6);
@@ -366,13 +379,14 @@ std::vector<std::string> SoapyLMS7::listGains(const int direction, const size_t
     std::vector<std::string> gains;
     if (direction == SOAPY_SDR_RX)
     {
-        gains.push_back("LNA");
         gains.push_back("TIA");
+        gains.push_back("LNA");
         gains.push_back("PGA");
     }
     if (direction == SOAPY_SDR_TX)
     {
         gains.push_back("PAD");
+        gains.push_back("IAMP");
     }
     return gains;
 }
@@ -385,17 +399,17 @@ void SoapyLMS7::setGain(const int direction, const size_t channel, const double
     //This differs from the default gain distribution in that it
     //does not scale the gain to the negative range of the PGA.
     //This keep the PGA in mid-range unless extreme values are used.
-    if (direction == SOAPY_SDR_RX)
+    double remaining(value);
+    for (const auto &name : this->listGains(direction, channel))
     {
-        double remaining(value);
-        for (const auto &name : this->listGains(direction, channel))
-        {
-            this->setGain(direction, channel, name, remaining);
-            remaining -= this->getGain(direction, channel, name);
-        }
+        this->setGain(direction, channel, name, remaining);
+        remaining -= this->getGain(direction, channel, name);
     }
+}
 
-    else SoapySDR::Device::setGain(direction, channel, value);
+double SoapyLMS7::getGain(const int direction, const size_t channel) const
+{
+    return SoapySDR::Device::getGain(direction, channel)-12.0;
 }
 
 void SoapyLMS7::setGain(const int direction, const size_t channel, const std::string &name, const double value)
@@ -414,11 +428,6 @@ void SoapyLMS7::setGain(const int direction, const size_t channel, const std::st
         rfic->SetRFELoopbackLNA_dB(value);
     }
 
-    else if (direction == SOAPY_SDR_RX and name == "LB_LNA")
-    {
-        rfic->SetRFELoopbackLNA_dB(value);
-    }
-
     else if (direction == SOAPY_SDR_RX and name == "TIA")
     {
         rfic->SetRFETIA_dB(value);
@@ -433,10 +442,10 @@ void SoapyLMS7::setGain(const int direction, const size_t channel, const std::st
     {
         rfic->SetTRFPAD_dB(value);
     }
-
-    else if (direction == SOAPY_SDR_TX and name == "LB_PAD")
+    
+    else if (direction == SOAPY_SDR_TX and name == "IAMP")
     {
-        rfic->SetTRFLoopbackPAD_dB(value);
+        rfic->SetTBBIAMP_dB(value);
     }
 
     else if (direction == SOAPY_SDR_TX and name == "LB_PAD")
@@ -478,6 +487,11 @@ double SoapyLMS7::getGain(const int direction, const size_t channel, const std::
     {
         return rfic->GetTRFPAD_dB();
     }
+    
+    else if (direction == SOAPY_SDR_TX and name == "IAMP")
+    {
+        return rfic->GetTBBIAMP_dB();
+    }
 
     else if (direction == SOAPY_SDR_TX and name == "LB_PAD")
     {
@@ -494,7 +508,8 @@ SoapySDR::Range SoapyLMS7::getGainRange(const int direction, const size_t channe
         //make it so gain of 0.0 sets PGA at its mid-range
         return SoapySDR::Range(-12.0, 19.0+12.0+30.0);
     }
-    return SoapySDR::Device::getGainRange(direction, channel);
+    else
+        return SoapySDR::Range(-12.0, 52.0+12.0);
 }
 
 SoapySDR::Range SoapyLMS7::getGainRange(const int direction, const size_t channel, const std::string &name) const
@@ -503,7 +518,8 @@ SoapySDR::Range SoapyLMS7::getGainRange(const int direction, const size_t channe
     if (direction == SOAPY_SDR_RX and name == "LB_LNA") return SoapySDR::Range(0.0, 40.0);
     if (direction == SOAPY_SDR_RX and name == "TIA") return SoapySDR::Range(0.0, 12.0);
     if (direction == SOAPY_SDR_RX and name == "PGA") return SoapySDR::Range(-12.0, 19.0);
-    if (direction == SOAPY_SDR_TX and name == "PAD") return SoapySDR::Range(-52.0, 0.0);
+    if (direction == SOAPY_SDR_TX and name == "PAD") return SoapySDR::Range(0.0, 52.0);
+    if (direction == SOAPY_SDR_TX and name == "IAMP") return SoapySDR::Range(-12.0, 12.0);
     if (direction == SOAPY_SDR_TX and name == "LB_PAD") return SoapySDR::Range(-4.3, 0.0);
     return SoapySDR::Device::getGainRange(direction, channel, name);
 }
@@ -1075,6 +1091,44 @@ std::string SoapyLMS7::readSensor(const int direction, const size_t channel, con
  * Register API
  ******************************************************************/
 
+std::vector<std::string> SoapyLMS7::listRegisterInterfaces(void) const
+{
+    std::vector<std::string> ifaces;
+    ifaces.push_back("BBIC");
+    for (size_t i = 0; i < _rfics.size(); i++)
+    {
+        ifaces.push_back("RFIC" + std::to_string(i));
+    }
+    return ifaces;
+}
+
+void SoapyLMS7::writeRegister(const std::string &name, const unsigned addr, const unsigned value)
+{
+    if (name == "BBIC") return this->writeRegister(addr, value);
+    for (size_t i = 0; i < _rfics.size(); i++)
+    {
+        if (("RFIC" + std::to_string(i)) != name) continue;
+        int st = _rfics[i]->SPI_write(addr, value);
+        if (st == 0) return;
+        throw std::runtime_error("SoapyLMS7::WriteRegister("+name+", "+std::to_string(addr)+") FAIL");
+    }
+    throw std::runtime_error("SoapyLMS7::WriteRegister("+name+") unknown interface");
+}
+
+unsigned SoapyLMS7::readRegister(const std::string &name, const unsigned addr) const
+{
+    if (name == "BBIC") return this->readRegister(addr);
+    for (size_t i = 0; i < _rfics.size(); i++)
+    {
+        if (("RFIC" + std::to_string(i)) != name) continue;
+        int st(0);
+        int value = _rfics[i]->SPI_read(addr, true, &st);
+        if (st == 0) return value;
+        throw std::runtime_error("SoapyLMS7::readRegister("+name+", "+std::to_string(addr)+") FAIL");
+    }
+    throw std::runtime_error("SoapyLMS7::readRegister("+name+") unknown interface");
+}
+
 void SoapyLMS7::writeRegister(const unsigned addr, const unsigned value)
 {
     auto st = _conn->WriteRegister(addr, value);
