@@ -7,6 +7,7 @@
 
 #include "lms7_device.h"
 #include "qLimeSDR.h"
+#include "LimeSDR_mini.h"
 #include "GFIR/lms_gfir.h"
 #include "IConnection.h"
 #include <cmath>
@@ -32,7 +33,9 @@ LMS7_Device* LMS7_Device::CreateDevice(lime::IConnection* conn, LMS7_Device *obj
     if (conn != nullptr)
     {
         auto info = conn->GetDeviceInfo();
-        if (info.deviceName == "LimeSDR-QPCIe")
+        if (info.deviceName == "LimeSDR-mini")
+            device = new LMS7_LimeSDR_mini(obj);
+        else if (info.deviceName == "LimeSDR-QPCIe")
             device = new LMS7_qLimeSDR(obj);
         else
             device = new LMS7_Device(obj);
@@ -70,18 +73,23 @@ LMS7_Device::~LMS7_Device()
 	lime::ConnectionRegistry::freeConnection(this->connection);
 }
 
+unsigned LMS7_Device::GetLMSCnt() const
+{
+    return 1;
+}
+
 void LMS7_Device::_Initialize(lime::IConnection* conn)
 {
     this->tx_channels.resize(this->GetNumChannels());
     this->rx_channels.resize(this->GetNumChannels());
 
-    while (this->lms_list.size() > this->GetNumChannels()/2)
+    while (this->lms_list.size() > GetLMSCnt())
     {
         delete this->lms_list.back();
         this->lms_list.pop_back();
     }
 
-    while (this->lms_list.size() < this->GetNumChannels()/2)
+    while (this->lms_list.size() < GetLMSCnt())
     {
         this->lms_list.push_back(new lime::LMS7002M());
     }
@@ -137,7 +145,7 @@ int LMS7_Device::ConfigureRXLPF(bool enabled,int ch,float_type bandwidth)
         lms->Modify_SPI_Reg_bits(LMS7param(PD_LPFH_RBB),1,true);
         lms->Modify_SPI_Reg_bits(LMS7param(INPUT_CTL_PGA_RBB),2,true);
     }
-
+    lime::info("RX LPF configured");
     return 0;
 }
 
@@ -327,6 +335,7 @@ int LMS7_Device::ConfigureTXLPF(bool enabled,int ch,double bandwidth)
         lms->Modify_SPI_Reg_bits(LMS7param(PD_LPFS5_TBB), 1, true);
         return lms->Modify_SPI_Reg_bits(LMS7param(PD_LPFH_TBB), 1, true);
     }
+    lime::info("TX LPF configured");
     return 0;
 }
 
@@ -337,72 +346,56 @@ size_t LMS7_Device::GetNumChannels(const bool tx) const
 
 int LMS7_Device::SetRate(double f_Hz, int oversample)
 {
-   int decim = 0;
-   float_type nco_f=0;
-   for (size_t i = 0; i < GetNumChannels(false);i++)
-   {
-        if (rx_channels[i].cF_offset_nco > nco_f)
-            nco_f = rx_channels[i].cF_offset_nco;
-        if (tx_channels[i].cF_offset_nco > nco_f)
-            nco_f = tx_channels[i].cF_offset_nco;
-        tx_channels[i].sample_rate = f_Hz;
-        rx_channels[i].sample_rate = f_Hz;
-   }
+    float_type nco_f=0;
+    for (size_t i = 0; i < GetNumChannels(false);i++)
+    {
+         if (rx_channels[i].cF_offset_nco > nco_f)
+             nco_f = rx_channels[i].cF_offset_nco;
+         if (tx_channels[i].cF_offset_nco > nco_f)
+             nco_f = tx_channels[i].cF_offset_nco;
+         tx_channels[i].sample_rate = f_Hz;
+         rx_channels[i].sample_rate = f_Hz;
+    }
 
-   if (nco_f != 0)
-   {
-       int nco_over = 2+2*(nco_f-1)/f_Hz;
-       oversample = oversample > nco_over ? oversample : nco_over;
-       if (oversample > 32)
-       {
-           lime::ReportError(ERANGE, "Cannot achieve desired sample rate: rate too low");
-           return -1;
-       }
-   }
-
-    if (oversample == 0)
-        oversample =  LMS_CGEN_MAX/(8*f_Hz);
-
-   if (oversample > 1)
-   {
-       for (decim = 0; decim < 4; decim++)
-       {
-            if ( (1<<decim) >= (oversample+1)/2)
-                break;
-       }
-   }
-   else decim = 7;
-
-   int ratio = oversample <= 2 ? 2 : (2<<decim);
-   float_type cgen = f_Hz*4*ratio;
-   if (cgen > LMS_CGEN_MAX)
-   {
-       lime::ReportError(ERANGE, "Cannot set desired sample rate. CGEN clock out of range");
-       return -1;
-   }
-   for (unsigned i = 0; i < lms_list.size(); i++)
-   {
-        lime::LMS7002M* lms = lms_list[i];
-       if ((lms->SetFrequencyCGEN(cgen) != 0)
-           || (lms->Modify_SPI_Reg_bits(LMS7param(EN_ADCCLKH_CLKGN), 0) != 0)
-           || (lms->Modify_SPI_Reg_bits(LMS7param(CLKH_OV_CLKL_CGEN), 2) != 0)
-           || (lms->Modify_SPI_Reg_bits(LMS7param(MAC), 2, true) != 0)
-           || (lms->Modify_SPI_Reg_bits(LMS7param(HBD_OVR_RXTSP), decim) != 0)
-           || (lms->Modify_SPI_Reg_bits(LMS7param(HBI_OVR_TXTSP), decim) != 0)
-           || (lms->Modify_SPI_Reg_bits(LMS7param(MAC), 1, true) != 0)
-           || (lms->SetInterfaceFrequency(lms->GetFrequencyCGEN(), decim, decim) != 0))
-           return -1;
-
-        float_type fpgaTxPLL = lms->GetReferenceClk_TSP(lime::LMS7002M::Tx);
-        float_type fpgaRxPLL = lms->GetReferenceClk_TSP(lime::LMS7002M::Rx);
-        if (decim != 7)
+    if (nco_f != 0)
+    {
+        int nco_over = 2+2*(nco_f-1)/f_Hz;
+        oversample = oversample > nco_over ? oversample : nco_over;
+        if (oversample > 32)
         {
-            fpgaTxPLL /= pow(2.0, decim);
-            fpgaRxPLL /= pow(2.0, decim);
+            lime::ReportError(ERANGE, "Cannot achieve desired sample rate: rate too low");
+            return -1;
         }
-        if (this->connection->UpdateExternalDataRate(i, fpgaTxPLL / 2, fpgaRxPLL / 2) != 0)
-           return -1;
-   }
+    }
+    else if (oversample == 0)
+        oversample = LMS_CGEN_MAX/(4*f_Hz);
+    
+    int decim = 5;
+    while (--decim)
+        if ((2<<decim) <= oversample)
+            break;
+    oversample = 2<<decim;
+    
+    for (unsigned i = 0; i < lms_list.size(); i++)
+    {
+         lime::LMS7002M* lms = lms_list[i];
+        if ((lms->SetFrequencyCGEN(f_Hz*4*oversample) != 0)
+            || (lms->Modify_SPI_Reg_bits(LMS7param(EN_ADCCLKH_CLKGN), 0) != 0)
+            || (lms->Modify_SPI_Reg_bits(LMS7param(CLKH_OV_CLKL_CGEN), 2) != 0)
+            || (lms->Modify_SPI_Reg_bits(LMS7param(MAC), 2, true) != 0)
+            || (lms->Modify_SPI_Reg_bits(LMS7param(HBD_OVR_RXTSP), decim) != 0)
+            || (lms->Modify_SPI_Reg_bits(LMS7param(HBI_OVR_TXTSP), decim) != 0)
+            || (lms->Modify_SPI_Reg_bits(LMS7param(MAC), 1, true) != 0)
+            || (lms->SetInterfaceFrequency(lms->GetFrequencyCGEN(), decim, decim) != 0))
+            return -1;
+
+         float_type fpgaTxPLL = lms->GetReferenceClk_TSP(lime::LMS7002M::Tx);
+         float_type fpgaRxPLL = lms->GetReferenceClk_TSP(lime::LMS7002M::Rx);
+         fpgaTxPLL /= pow(2.0, decim);
+         fpgaRxPLL /= pow(2.0, decim);
+         if (this->connection->UpdateExternalDataRate(i, fpgaTxPLL / 2, fpgaRxPLL / 2) != 0)
+            return -1;
+    }
 
     for (size_t i = 0; i < GetNumChannels(false);i++)
     {
@@ -433,18 +426,17 @@ int LMS7_Device::SetRate(bool tx, double f_Hz, unsigned oversample)
 
     int decimation;
     int interpolation;
-    size_t tmp;
 
-   float_type nco_rx=0;
-   float_type nco_tx=0;
-   int min_int = 1;
-   int min_dec = 1;
-   bool retain_nco = false;
+    float_type nco_rx=0;
+    float_type nco_tx=0;
+    int min_int = 1;
+    int min_dec = 1;
+    bool retain_nco = false;
 
-   lime::LMS7002M* lms = lms_list[0];
+    lime::LMS7002M* lms = lms_list[0];
 
-   for (size_t i = 0; i < GetNumChannels(false);i++)
-   {
+    for (size_t i = 0; i < GetNumChannels(false);i++)
+    {
         if (rx_channels[i].cF_offset_nco > nco_rx)
             nco_rx = rx_channels[i].cF_offset_nco;
         if (tx_channels[i].cF_offset_nco > nco_tx)
@@ -453,38 +445,30 @@ int LMS7_Device::SetRate(bool tx, double f_Hz, unsigned oversample)
             tx_channels[i].sample_rate = f_Hz;
         else
             rx_channels[i].sample_rate = f_Hz;
-   }
+    }
 
-   if (nco_rx != 0 || nco_tx != 0)
-   {
-       retain_nco = true;
-       min_int = 2+2*(nco_tx-1)/tx_channels[0].sample_rate;
-       min_dec = 2+2*(nco_rx-1)/rx_channels[0].sample_rate;
-       unsigned int nco_over = tx ? min_int : min_dec;
-       oversample = oversample > nco_over ? oversample : nco_over;
-       if (oversample > 32)
-       {
-           lime::ReportError(ERANGE, "Cannot achieve desired sample rate: rate too low");
-           return -1;
-       }
-   }
-
-    if (oversample == 0)
-        oversample = tx ? LMS_CGEN_MAX/(2*f_Hz) : LMS_CGEN_MAX/(8*f_Hz);
-
-    if (oversample > 1)
+    if (nco_rx != 0 || nco_tx != 0)
     {
-        for (tmp = 0; tmp < 4; tmp++)
+        retain_nco = true;
+        min_int = 2+2*(nco_tx-1)/tx_channels[0].sample_rate;
+        min_dec = 2+2*(nco_rx-1)/rx_channels[0].sample_rate;
+        unsigned int nco_over = tx ? min_int : min_dec;
+        oversample = oversample > nco_over ? oversample : nco_over;
+        if (oversample > 32)
         {
-            if ( size_t(1<<tmp) >= (oversample+1)/2)
-            {
-                break;
-            }
+            lime::ReportError(ERANGE, "Cannot achieve desired sample rate: rate too low");
+            return -1;
         }
     }
-    else tmp = 7;
+    else if (oversample == 0)
+        oversample = tx ? LMS_CGEN_MAX/f_Hz : LMS_CGEN_MAX/(4*f_Hz);
+   
+    size_t tmp = 5;
+    while (--tmp)
+        if ((2<<tmp) <= oversample)
+            break;
 
-    int ratio = oversample <= 2 ? 2 : (2<<tmp);
+    int ratio = 2<<tmp;
 
     if (tx)
     {
@@ -626,12 +610,12 @@ int LMS7_Device::SetRate(bool tx, double f_Hz, unsigned oversample)
 
     if (tx)
     {
-        ratio = oversample <= 2 ? 2 : (2<<interpolation);
+        ratio = 2<<interpolation;
         cgen = f_Hz*ratio;
     }
     else
     {
-        ratio = oversample <= 2 ? 2 : (2<<decimation);
+        ratio = 2<<decimation;
         cgen = f_Hz * ratio * 4;
     }
 
@@ -673,12 +657,8 @@ int LMS7_Device::SetRate(bool tx, double f_Hz, unsigned oversample)
 
 	float_type fpgaTxPLL = lms->GetReferenceClk_TSP(lime::LMS7002M::Tx);
 	float_type fpgaRxPLL = lms->GetReferenceClk_TSP(lime::LMS7002M::Rx);
-	if (interpolation != 7) {
-	  fpgaTxPLL /= pow(2.0, interpolation);
-	}
-	if (decimation != 7) {
-	  fpgaRxPLL /= pow(2.0, decimation);
-	}
+	fpgaTxPLL /= pow(2.0, interpolation);
+	fpgaRxPLL /= pow(2.0, decimation);
         if (this->connection->UpdateExternalDataRate(i, fpgaTxPLL / 2, fpgaRxPLL / 2) != 0)
 	  return -1;
       }
@@ -811,21 +791,6 @@ lms_range_t LMS7_Device::GetRxPathBand(size_t path, size_t chan) const
 {
   lms_range_t ret;
   ret.step = 1;
-  if (this->connection->GetDeviceInfo().deviceName == lime::GetDeviceName(lime::LMS_DEV_ULIMESDR))
-  {
-      if (path == LMS_PATH_LNAL)
-      {
-        ret.max = 3800000000;
-        ret.min = 30000000;
-      }
-      else
-      {
-            ret.max = 0;
-            ret.min = 0;
-            ret.step = 0;
-      }
-  }
-  else
   switch (path)
   {
       case LMS_PATH_LNAH:
@@ -855,21 +820,6 @@ lms_range_t LMS7_Device::GetTxPathBand(size_t path, size_t chan) const
   lms_range_t ret;
 
   ret.step = 1;
-  if (this->connection->GetDeviceInfo().deviceName == lime::GetDeviceName(lime::LMS_DEV_ULIMESDR))
-  {
-      if (path == LMS_PATH_TX2)
-      {
-        ret.max = 3800000000;
-        ret.min = 30000000;
-      }
-      else
-      {
-            ret.max = 0;
-            ret.min = 0;
-            ret.step = 0;
-      }
-  }
-  else
   switch (path)
   {
       case LMS_PATH_TX2:
@@ -1075,21 +1025,20 @@ int LMS7_Device::SetGFIRCoef(bool tx, size_t chan, lms_gfir_t filt, const float_
 int LMS7_Device::GetGFIRCoef(bool tx, size_t chan, lms_gfir_t filt, float_type* coef)
 {
     lime::LMS7002M* lms = lms_list[chan / 2];
-    if (lms->Modify_SPI_Reg_bits(LMS7param(MAC), (chan%2) + 1, true) != 0)
-       return -1;
-   int16_t coef16[120];
+    lms->Modify_SPI_Reg_bits(LMS7param(MAC), (chan%2) + 1, true);
+    int16_t coef16[120];
 
-   if (lms->GetGFIRCoefficients(tx, filt, coef16, filt == LMS_GFIR3 ? 120 : 40) != 0)
-       return -1;
-   if (coef != NULL)
-   {
-       for (int i = 0; i < (filt==LMS_GFIR3 ? 120 : 40) ; i++)
-       {
-           coef[i] = coef16[i];
-           coef[i] /= (1<<15);
-       }
-   }
-   return (filt==LMS_GFIR3) ? 120 : 40;
+    if (lms->GetGFIRCoefficients(tx, filt, coef16, filt == LMS_GFIR3 ? 120 : 40) != 0)
+        return -1;
+    if (coef != NULL)
+    {
+        for (int i = 0; i < (filt==LMS_GFIR3 ? 120 : 40) ; i++)
+        {
+            coef[i] = coef16[i];
+            coef[i] /= (1<<15);
+        }
+    }
+    return (filt==LMS_GFIR3) ? 120 : 40;
 }
 
 int LMS7_Device::SetGFIR(bool tx, size_t chan, lms_gfir_t filt, bool enabled)
@@ -1682,12 +1631,11 @@ int LMS7_Device::Init()
         {0x0022, 0x07FF}, {0x0023, 0x5550}, {0x002B, 0x0038}, {0x002C, 0x0000},
         {0x002D, 0x0641}, {0x0086, 0x4101}, {0x0087, 0x5555}, {0x0088, 0x0525},
         {0x0089, 0x1078}, {0x008B, 0x1F8C}, {0x008C, 0x267B}, {0x00A6, 0x000F},
-        {0x00A9, 0x8000}, {0x00AC, 0x2000}, {0x0108, 0x3026}, {0x010C, 0x8865},
-        {0x010E, 0x0000}, {0x0110, 0x0BFF}, {0x0113, 0x03C2}, {0x011C, 0xA941},
-        {0x011D, 0x0000}, {0x011E, 0x0984}, {0x0120, 0xB9FF}, {0x0121, 0x3650},
-        {0x0122, 0x033F}, {0x0123, 0x267B}, {0x0200, 0x00E1}, {0x0208, 0x0170},
-        {0x020B, 0x4000}, {0x020C, 0x8000}, {0x0400, 0x8081}, {0x040B, 0x1020},
-        {0x040C, 0x00F8}
+        {0x00A9, 0x8000}, {0x00AC, 0x2000}, {0x0108, 0x318C}, {0x010C, 0x8865},
+        {0x010E, 0x0000}, {0x0110, 0x2B14}, {0x0113, 0x03C2}, {0x011C, 0xA941},
+        {0x011D, 0x0000}, {0x011E, 0x0984}, {0x0121, 0x3650}, {0x0122, 0x033F},
+        {0x0123, 0x267B}, {0x0200, 0x00E1}, {0x0208, 0x0170}, {0x020B, 0x4000},
+        {0x020C, 0x8000}, {0x0400, 0x8081}, {0x040B, 0x1020}, {0x040C, 0x00F8}
     };
 
     for (unsigned i = 0; i < lms_list.size(); i++)
@@ -1711,6 +1659,12 @@ int LMS7_Device::Init()
 
         if (lms->UploadAll()!=0)
             return -1;
+        if (SetTxFrequency(0,1250e6)!=0)
+            return -1;
+        if (SetRxFrequency(0,1200e6)!=0)
+            return -1;
+        if (SetRate(10e6,2)!=0)
+            return -1;
     }
     return 0;
 }
@@ -1746,6 +1700,9 @@ int LMS7_Device::EnableChannel(bool dir_tx, size_t chan, bool enabled)
 
 int LMS7_Device::Program(const char* data, size_t len, lms_prog_trg_t target, lms_prog_md_t mode, lime::IConnection::ProgrammingCallback callback)
 {
+    if (connection == nullptr)
+        return lime::ReportError(EINVAL, "Device not connected");
+    
     switch (target)
     {
         case LMS_PROG_TRG_FX3:
@@ -1774,7 +1731,9 @@ int LMS7_Device::Program(const char* data, size_t len, lms_prog_trg_t target, lm
                 prog_mode = lime::IConnection::MCU_PROG_MODE::EEPROM_AND_SRAM;
             else
             {
-                mcu->Reset_MCU();
+                auto lms = lms_list.at(lms_chip_id);
+                lms->SPI_write(0x0002, 0x0000);
+                lms->SPI_write(0x0002, 0x0003);
                 return 0;
             }
 
@@ -1795,6 +1754,9 @@ int LMS7_Device::Program(const char* data, size_t len, lms_prog_trg_t target, lm
 
 int LMS7_Device::ProgramUpdate(const bool download,lime::IConnection::ProgrammingCallback callback)
 {
+    if (connection == nullptr)
+        return lime::ReportError(EINVAL, "Device not connected");
+
     return this->connection->ProgramUpdate(download,callback);
 }
 
@@ -2073,6 +2035,9 @@ lime::LMS7002M* LMS7_Device::GetLMS(int index)
 
 int LMS7_Device::UploadWFM(const void **samples, uint8_t chCount, int sample_count, lime::StreamConfig::StreamDataFormat fmt)
 {
+    if (connection == nullptr)
+        return lime::ReportError(EINVAL, "Device not connected");
+    
     return connection->UploadWFM(samples, chCount%2 ? 1 : 2, sample_count, fmt, (chCount-1)/2);
 }
 
