@@ -7,8 +7,8 @@
 #ifndef ICONNECTION_H
 #define ICONNECTION_H
 
-#include <LimeSuiteConfig.h>
-#include <ConnectionHandle.h>
+#include "LimeSuiteConfig.h"
+#include "ConnectionHandle.h"
 #include <string>
 #include <vector>
 #include <cstring> //memset
@@ -249,7 +249,7 @@ public:
      * Typically this will reset the RFIC using a GPIO,
      * and possibly other ICs located on the device.
      */
-    virtual int DeviceReset(void);
+    virtual int DeviceReset(int ind=0);
 
     /*!
      * Called by the LMS7002M driver after potential band-selection changes.
@@ -652,6 +652,8 @@ public:
         enum
         {
             SYNC_TIMESTAMP = 1,
+            END_BURST = 2,
+            OVERWRITE_OLD = 4,
         };
         uint64_t timestamp;
         uint32_t flags;
