@@ -211,9 +211,9 @@ int ConnectionSTREAM::ReadRawStreamData(char* buffer, unsigned length, int epInd
 void ConnectionSTREAM::ReceivePacketsLoop(Streamer* stream)
 {
     //at this point FPGA has to be already configured to output samples
-    const uint8_t chCount = stream->mRxStreams.size();
+    const uint8_t chCount = stream->streamSize;
     const bool packed = stream->mRxStreams[0]->config.linkFormat == StreamConfig::STREAM_12_BIT_COMPRESSED;
-    const uint32_t samplesInPacket = (packed  ? 1360 : 1020)/chCount;
+    const uint32_t samplesInPacket = (packed  ? samples12InPkt : samples16InPkt)/chCount;
     const unsigned char ep = 0x81;
 
     const uint8_t packetsToBatch = stream->rxBatchSize;
@@ -269,11 +269,20 @@ void ConnectionSTREAM::ReceivePacketsLoop(Streamer* stream)
         if(handles[bi] >= 0)
         {
             if (this->WaitForReading(handles[bi], 1000) == true)
+            {
                 bytesReceived = this->FinishDataReading(&buffers[bi*bufferSize], bufferSize, handles[bi]);
-            totalBytesReceived += bytesReceived;
-            if (bytesReceived != int32_t(bufferSize)) //data should come in full sized packets
-                for(auto value: stream->mRxStreams)
-                    value->underflow++;
+                totalBytesReceived += bytesReceived;
+                if (bytesReceived != int32_t(bufferSize)) //data should come in full sized packets
+                    for(auto value: stream->mRxStreams)
+                        if (value && value->mActive)
+                            value->underflow++;
+            }
+            else
+            { 
+                stream->rxDataRate_Bps.store(totalBytesReceived); 
+                totalBytesReceived = 0;
+                continue;
+            }
         }
         bool txLate=false;
         for (uint8_t pktIndex = 0; pktIndex < bytesReceived / sizeof(FPGA_DataPacket); ++pktIndex)
@@ -292,7 +301,8 @@ void ConnectionSTREAM::ReceivePacketsLoop(Streamer* stream)
                     resetFlagsDelay = packetsToBatch*buffersCount;
                     stream->txLastLateTime.store(pkt[pktIndex].counter);
                     for(auto value: stream->mTxStreams)
-                        value->pktLost++;
+                        if (value && value->mActive)
+                            value->pktLost++;
                 }
             }
             uint8_t* pktStart = (uint8_t*)pkt[pktIndex].data;
@@ -303,7 +313,8 @@ void ConnectionSTREAM::ReceivePacketsLoop(Streamer* stream)
                 printf("\tRx pktLoss: ts diff: %li  pktLoss: %i\n", pkt[pktIndex].counter - prevTs, packetLoss);
 #endif
                 for(auto value: stream->mRxStreams)
-                    value->pktLost += packetLoss;
+                    if (value && value->mActive)
+                        value->pktLost += packetLoss;
             }
             prevTs = pkt[pktIndex].counter;
             stream->rxLastTimestamp.store(prevTs);
@@ -315,6 +326,8 @@ void ConnectionSTREAM::ReceivePacketsLoop(Streamer* stream)
 
             for(int ch=0; ch<chCount; ++ch)
             {
+                if (stream->mRxStreams[ch]==nullptr || stream->mRxStreams[ch]->mActive==false)
+                    continue;
                 IStreamChannel::Metadata meta;
                 meta.timestamp = pkt[pktIndex].counter;
                 meta.flags = IStreamChannel::Metadata::OVERWRITE_OLD;
@@ -363,7 +376,7 @@ void ConnectionSTREAM::TransmitPacketsLoop(Streamer* stream)
 {
     //at this point FPGA has to be already configured to output samples
     const uint8_t maxChannelCount = 2;
-    const uint8_t chCount = stream->mTxStreams.size();
+    const uint8_t chCount = stream->streamSize;
     const bool packed = stream->mTxStreams[0]->config.linkFormat == StreamConfig::STREAM_12_BIT_COMPRESSED;
     const unsigned char ep  = 0x01;
 
@@ -372,9 +385,10 @@ void ConnectionSTREAM::TransmitPacketsLoop(Streamer* stream)
     const uint32_t bufferSize = packetsToBatch*sizeof(FPGA_DataPacket);
     const uint32_t popTimeout_ms = 500;
 
-    const int maxSamplesBatch = (packed ? 1360:1020)/chCount;
+    const int maxSamplesBatch = (packed ? samples12InPkt:samples16InPkt)/chCount;
     vector<int> handles(buffersCount, 0);
     vector<bool> bufferUsed(buffersCount, 0);
+    vector<uint32_t> bytesToSend(buffersCount, 0);
     vector<complex16_t> samples[maxChannelCount];
     vector<char> buffers;
     try
@@ -398,34 +412,48 @@ void ConnectionSTREAM::TransmitPacketsLoop(Streamer* stream)
         if (bufferUsed[bi])
         {
     	    unsigned bytesSent = 0;
-            if (this->WaitForSending(handles[bi], 1000) == true) {
-                bytesSent = this->FinishDataSending(&buffers[bi*bufferSize], bufferSize, handles[bi]);
-	    }
-
-            if (bytesSent != bufferSize) {
-	      for (auto value : stream->mTxStreams) {
-		value->overflow++;
-	      }
+            if (this->WaitForSending(handles[bi], 1000) == true)
+            {
+                bytesSent = this->FinishDataSending(&buffers[bi*bufferSize], bytesToSend[bi], handles[bi]);
+	    
+                if (bytesSent != bytesToSend[bi])
+                {
+                    for (auto value : stream->mTxStreams)
+                        if (value && value->mActive)
+                            value->overflow++;
+                }
+                else 
+                    totalBytesSent += bytesSent;
+                bufferUsed[bi] = false;
+            }
+            else
+            {
+                stream->txDataRate_Bps.store(totalBytesSent);
+                totalBytesSent = 0;
+                continue;
             }
-            else {
-                totalBytesSent += bytesSent;
-	    }
-            bufferUsed[bi] = false;
         }
         int i=0;
 
         while(i<packetsToBatch && stream->terminateTx.load() != true)
         {
+            bool end_burst = false;
             IStreamChannel::Metadata meta;
             FPGA_DataPacket* pkt = reinterpret_cast<FPGA_DataPacket*>(&buffers[bi*bufferSize]);
             for(int ch=0; ch<chCount; ++ch)
             {
+                if (stream->mTxStreams[ch]==nullptr || stream->mTxStreams[ch]->mActive==false)
+                {
+                    memset(&samples[ch][0],0,maxSamplesBatch*sizeof(complex16_t));
+                    continue;
+                }
                 int samplesPopped = stream->mTxStreams[ch]->Read(samples[ch].data(), maxSamplesBatch, &meta, popTimeout_ms);
                 if (samplesPopped != maxSamplesBatch)
                 {
                     if (meta.flags & IStreamChannel::Metadata::END_BURST)
                     {
-                        memset(&samples[ch][samplesPopped],0,maxSamplesBatch-samplesPopped);
+                        memset(&samples[ch][samplesPopped],0,(maxSamplesBatch-samplesPopped)*sizeof(complex16_t));
+                        end_burst = true;
                         continue;
                     }
                     stream->mTxStreams[ch]->underflow++;
@@ -437,8 +465,6 @@ void ConnectionSTREAM::TransmitPacketsLoop(Streamer* stream)
                 }
             }
 
-            if(stream->terminateTx.load() == true) //early termination
-                break;
             pkt[i].counter = meta.timestamp;
             pkt[i].reserved[0] = 0;
             //by default ignore timestamps
@@ -451,11 +477,15 @@ void ConnectionSTREAM::TransmitPacketsLoop(Streamer* stream)
             uint8_t* const dataStart = (uint8_t*)pkt[i].data;
             fpga::Samples2FPGAPacketPayload(src.data(), maxSamplesBatch, chCount==2, packed, dataStart);
             ++i;
-            if (meta.flags & IStreamChannel::Metadata::END_BURST)
+            if (end_burst)
                 break;
         }
+        
+        if(stream->terminateTx.load() == true) //early termination
+            break;
 
-        handles[bi] = this->BeginDataSending(&buffers[bi*bufferSize], i*sizeof(FPGA_DataPacket), ep);
+        bytesToSend[bi] = i*sizeof(FPGA_DataPacket);
+        handles[bi] = this->BeginDataSending(&buffers[bi*bufferSize], bytesToSend[bi], ep);
         bufferUsed[bi] = true;
 
         t2 = chrono::high_resolution_clock::now();
