@@ -34,27 +34,27 @@ const ConnectionXillybus::EPConfig ConnectionXillybus::deviceConfigs[] = {
     {
         "\\\\.\\xillybus_read_8",
         "\\\\.\\xillybus_write_8",
-        {"\\\\.\\xillybus_read_32", "\\\\.\\xillybus_read_32"},
-        {"\\\\.\\xillybus_write_32", "\\\\.\\xillybus_write_32"}
+        {"\\\\.\\xillybus_read_32", "\\\\.\\xillybus_read_32", "\\\\.\\xillybus_read_32"},
+        {"\\\\.\\xillybus_write_32", "\\\\.\\xillybus_write_32", "\\\\.\\xillybus_write_32"}
     },
     {
         "\\\\.\\xillybus_control0_read_32",
         "\\\\.\\xillybus_control0_write_32",
-        {"\\\\.\\xillybus_stream0_read_32", "\\\\.\\xillybus_stream1_read_32"},
-        {"\\\\.\\xillybus_stream0_write_32", "\\\\.\\xillybus_stream1_write_32"}
+        {"\\\\.\\xillybus_stream0_read_32", "\\\\.\\xillybus_stream1_read_32", "\\\\.\\xillybus_stream2_read_32"},
+        {"\\\\.\\xillybus_stream0_write_32", "\\\\.\\xillybus_stream1_write_32", "\\\\.\\xillybus_stream2_write_32"}
     }
 #else
     {
         "/dev/xillybus_read_8",
         "/dev/xillybus_write_8",
-        {"/dev/xillybus_read_32", "/dev/xillybus_read_32"},
-        {"/dev/xillybus_write_32", "/dev/xillybus_write_32"}
+        {"/dev/xillybus_read_32", "/dev/xillybus_read_32", "/dev/xillybus_read_32"},
+        {"/dev/xillybus_write_32", "/dev/xillybus_write_32", "/dev/xillybus_write_32"}
     },
     {
         "/dev/xillybus_control0_read_32",
         "/dev/xillybus_control0_write_32",
-        {"/dev/xillybus_stream0_read_32", "/dev/xillybus_stream1_read_32"},
-        {"/dev/xillybus_stream0_write_32", "/dev/xillybus_stream1_write_32"}
+        {"/dev/xillybus_stream0_read_32", "/dev/xillybus_stream1_read_32", "/dev/xillybus_stream2_read_32"},
+        {"/dev/xillybus_stream0_write_32", "/dev/xillybus_stream1_write_32", "/dev/xillybus_stream2_write_32"}
     }
 #endif
 };
