@@ -76,6 +76,7 @@ double Connection_uLimeSDR::DetectRefClk(void)
     const double clkTbl[] = { 30.72e6, 38.4e6, 40e6, 52e6 };
     const uint32_t addr[] = { 0x61, 0x63 };
     const uint32_t vals[] = { 0x0, 0x0 };
+    SetReferenceClockRate(40e6);
     if (this->WriteRegisters(addr, vals, 2) != 0)
     {
         return -1;
@@ -218,6 +219,8 @@ int Connection_uLimeSDR::Open(const unsigned index, const int vid, const int pid
 	FT_SetStreamPipe(mFTHandle, FALSE, FALSE, 0x02, 64);
     FT_SetPipeTimeout(mFTHandle, 0x02, 500);
     FT_SetPipeTimeout(mFTHandle, 0x82, 500);
+    FT_SetPipeTimeout(mFTHandle, mStreamRdEndPtAddr, 0);
+    FT_SetPipeTimeout(mFTHandle, mStreamWrEndPtAddr, 0);
 	isConnected = true;
 	return 0;
 #else
@@ -244,6 +247,7 @@ int Connection_uLimeSDR::Open(const unsigned index, const int vid, const int pid
     }
     lime::debug("Claimed Interface");
     
+    FT_FlushPipe(0x82);  //clear ctrl ep rx buffer
     FT_SetStreamPipe(0x82,64);
     FT_SetStreamPipe(0x02,64);
     isConnected = true;
@@ -482,9 +486,8 @@ int Connection_uLimeSDR::BeginDataReading(char *buffer, uint32_t length)
         rxSize = length;
         FT_SetStreamPipe(mStreamRdEndPtAddr,rxSize);
     }
-    unsigned int Timeout = 500;
     libusb_transfer *tr = contexts[i].transfer;
-    libusb_fill_bulk_transfer(tr, dev_handle, mStreamRdEndPtAddr, (unsigned char*)buffer, length, callback_libusbtransfer, &contexts[i], Timeout);
+    libusb_fill_bulk_transfer(tr, dev_handle, mStreamRdEndPtAddr, (unsigned char*)buffer, length, callback_libusbtransfer, &contexts[i], 10000);
     contexts[i].done = false;
     contexts[i].bytesXfered = 0;
     contexts[i].bytesExpected = length;
@@ -634,9 +637,8 @@ int Connection_uLimeSDR::BeginDataSending(const char *buffer, uint32_t length)
         txSize = length;
         FT_SetStreamPipe(mStreamWrEndPtAddr,txSize);
     }
-    unsigned int Timeout = 500;
     libusb_transfer *tr = contextsToSend[i].transfer;
-    libusb_fill_bulk_transfer(tr, dev_handle, mStreamWrEndPtAddr, (unsigned char*)buffer, length, callback_libusbtransfer, &contextsToSend[i], Timeout);
+    libusb_fill_bulk_transfer(tr, dev_handle, mStreamWrEndPtAddr, (unsigned char*)buffer, length, callback_libusbtransfer, &contextsToSend[i], 10000);
     contextsToSend[i].done = false;
     contextsToSend[i].bytesXfered = 0;
     contextsToSend[i].bytesExpected = length;
