@@ -8,15 +8,15 @@
 #define FPGA_COMMON_H
 #include "IConnection.h"
 #include <stdint.h>
-#include <dataTypes.h>
+#include "dataTypes.h"
 
 namespace lime
 {
 namespace fpga
 {
-    int StartStreaming(IConnection* serPort, unsigned endpointIndex);
-    int StopStreaming(IConnection* serPort, unsigned endpointIndex);
-    int ResetTimestamp(IConnection* serPort, unsigned endpointIndex);
+    int StartStreaming(IConnection* serPort);
+    int StopStreaming(IConnection* serPort);
+    int ResetTimestamp(IConnection* serPort);
 
 struct FPGA_PLL_clock
 {
@@ -38,9 +38,8 @@ struct FPGA_PLL_clock
 int SetPllFrequency(IConnection* serPort, const uint8_t pllIndex, const double inputFreq, FPGA_PLL_clock* outputs, const uint8_t clockCount);
 int SetDirectClocking(IConnection* serPort, uint8_t clockIndex, const double inputFreq, const double phaseShift_deg);
 
-int FPGAPacketPayload2Samples(const uint8_t* buffer, const size_t bufLen, const size_t chCount, const int format, complex16_t** samples, size_t* samplesCount);
-int Samples2FPGAPacketPayload(const complex16_t* const* samples, const size_t samplesCount, const size_t chCount, const int format, uint8_t* buffer, size_t* bufLen);
-
+int FPGAPacketPayload2Samples(const uint8_t* buffer, int bufLen, bool mimo, bool compressed, complex16_t** samples);
+int Samples2FPGAPacketPayload(const complex16_t* const* samples, int samplesCount, bool mimo, bool compressed, uint8_t* buffer);
 }
 
 }
