@@ -412,23 +412,22 @@ void lms7002_pnlTxTSP_view::UpdateNCOinputs()
         }
         txtFCWPHOmodeAdditional->SetValue(wxString::Format(_("%3.3f"), pho));
         lblFCWPHOmodeName->SetLabel(_("PHO (deg)"));
-        tableTitleCol1->SetLabel(_("FCW(MHz)"));
-        tableTitleCol2->SetLabel(_("PHO(deg)"));
+        tableTitleCol1->SetLabel(_("FCW (MHz)"));
+        tableTitleCol2->SetLabel(_("PHO (deg)"));
     }
     else //PHO mode
     {
         float_type phase[16] = { 0 };
         float_type fcw = 0;
-        if (LMS_GetNCOPhase(lmsControl, LMS_CH_TX, ch, phase, &fcw) != 0)
-            return;
+        LMS_GetNCOPhase(lmsControl, LMS_CH_TX, ch, phase, &fcw);
         for (size_t i = 0; i < txtNCOinputs.size(); ++i)
         {
             txtNCOinputs[i]->SetValue(wxString::Format(_("%.3f"), (65536.0/360.0)*  phase[i]));
         }
         txtFCWPHOmodeAdditional->SetValue(wxString::Format(_("%.6f"), fcw/1e6));
-        lblFCWPHOmodeName->SetLabel(_("FCW(MHz)"));
-        tableTitleCol2->SetLabel(_("FCW(MHz)"));
-        tableTitleCol1->SetLabel(_("PHO(deg)"));
+        lblFCWPHOmodeName->SetLabel(_("FCW (MHz)"));
+        tableTitleCol2->SetLabel(_("FCW (MHz)"));
+        tableTitleCol1->SetLabel(_("PHO (deg)"));
     }
 }
 
