@@ -157,13 +157,15 @@ LMS7002M::LMS7002M() :
     MemorySectionAddresses[TRF][0] = 0x0100;
     MemorySectionAddresses[TRF][1] = 0x0104;
     MemorySectionAddresses[TBB][0] = 0x0105;
-    MemorySectionAddresses[TBB][1] = 0x010A;
+    MemorySectionAddresses[TBB][1] = 0x010B;
     MemorySectionAddresses[RFE][0] = 0x010C;
     MemorySectionAddresses[RFE][1] = 0x0114;
     MemorySectionAddresses[RBB][0] = 0x0115;
     MemorySectionAddresses[RBB][1] = 0x011A;
     MemorySectionAddresses[SX][0] = 0x011C;
     MemorySectionAddresses[SX][1] = 0x0124;
+    MemorySectionAddresses[TRX_GAIN][0] = 0x0125;
+    MemorySectionAddresses[TRX_GAIN][1] = 0x0126;
     MemorySectionAddresses[TxTSP][0] = 0x0200;
     MemorySectionAddresses[TxTSP][1] = 0x020C;
     MemorySectionAddresses[TxNCO][0] = 0x0240;
@@ -895,18 +897,15 @@ float_type LMS7002M::GetRFETIA_dB(void)
 
 int LMS7002M::SetTRFPAD_dB(const float_type value)
 {
-    const double pmax = 0;
-    double loss = pmax-value;
+    const double pmax = 52;
+    int loss_int = (pmax-value)+0.5;
 
     //different scaling realm
-    if (loss > 10) loss = (loss+10)/2;
+    if (loss_int > 10) loss_int = (loss_int+10)/2;
 
     //clip
-    if (loss > 31) loss = 31;
-    if (loss < 0) loss = 0;
-
-    //integer round
-    int loss_int = (int)(loss + 0.5);
+    if (loss_int > 31) loss_int = 31;
+    if (loss_int < 0) loss_int = 0;
 
     int ret = 0;
     ret |= this->Modify_SPI_Reg_bits(LMS7param(LOSS_LIN_TXPAD_TRF), loss_int);
@@ -916,7 +915,7 @@ int LMS7002M::SetTRFPAD_dB(const float_type value)
 
 float_type LMS7002M::GetTRFPAD_dB(void)
 {
-    const double pmax = 0;
+    const double pmax = 52;
     auto loss_int = this->Get_SPI_Reg_bits(LMS7param(LOSS_LIN_TXPAD_TRF));
     if (loss_int > 10) return pmax-10-2*(loss_int-10);
     return pmax-loss_int;
@@ -946,6 +945,33 @@ float_type LMS7002M::GetTRFLoopbackPAD_dB(void)
     return 0.0;
 }
 
+int LMS7002M::SetTBBIAMP_dB(const float_type gain)
+{
+   if (CalibrateTxGain(0,nullptr)!=0) //set optimal BB gain 
+       return -1;
+   if (gain != 0)
+   {
+         int g_iamp = Get_SPI_Reg_bits(LMS7param(CG_IAMP_TBB),true);
+         g_iamp = (float_type)g_iamp*pow(10.0,gain/20.0)+0.5;
+         Modify_SPI_Reg_bits(LMS7param(CG_IAMP_TBB),g_iamp > 63 ? 63 : g_iamp, true);
+   }
+   return 0;
+}
+
+float_type LMS7002M::GetTBBIAMP_dB(void)
+{
+    float_type gain = 0;
+    int g_current = Get_SPI_Reg_bits(LMS7param(CG_IAMP_TBB),true); 
+    if (CalibrateTxGain(0,nullptr)==0)
+    {
+        int g_optimal = Get_SPI_Reg_bits(LMS7param(CG_IAMP_TBB),true);
+        gain = 20.0*log10((float_type)g_current / (float_type) g_optimal);
+    }
+    Modify_SPI_Reg_bits(LMS7param(CG_IAMP_TBB),g_current, true); //restore
+    return gain;
+}
+
+
 int LMS7002M::SetPathRFE(PathRFE path)
 {
     int sel_path_rfe = 0;
@@ -1769,8 +1795,6 @@ int LMS7002M::SetGFIRCoefficients(bool tx, uint8_t GFIR_index, const int16_t *co
 */
 int LMS7002M::GetGFIRCoefficients(bool tx, uint8_t GFIR_index, int16_t *coef, uint8_t coefCount)
 {
-    checkConnection();
-
     int status = -1;
     uint8_t index;
     uint8_t coefLimit;
@@ -1796,7 +1820,7 @@ int LMS7002M::GetGFIRCoefficients(bool tx, uint8_t GFIR_index, int16_t *coef, ui
         addresses.push_back(startAddr + index + 24 * (index / 40));
     uint16_t spiData[120];
     memset(spiData, 0, 120 * sizeof(uint16_t));
-    if (controlPort->IsOpen())
+    if (controlPort && controlPort->IsOpen())
     {
         status = SPI_read_batch(&addresses[0], spiData, coefCount);
         for (index = 0; index < coefCount; ++index)
@@ -1988,12 +2012,12 @@ int LMS7002M::RegistersTest(const char* fileName)
     stringstream ss;
 
     //check single channel memory sections
-    vector<MemorySection> modulesToCheck = { AFE, BIAS, XBUF, CGEN, LDO, BIST, CDS, TRF, TBB, RFE, RBB, SX,
+    vector<MemorySection> modulesToCheck = { AFE, BIAS, XBUF, CGEN, BIST, CDS, TRF, TBB, RFE, RBB, SX,
         TxTSP, TxNCO, TxGFIR1, TxGFIR2, TxGFIR3a, TxGFIR3b, TxGFIR3c,
-        RxTSP, RxNCO, RxGFIR1, RxGFIR2, RxGFIR3a, RxGFIR3b, RxGFIR3c, LimeLight };
-    const char* moduleNames[] = { "AFE", "BIAS", "XBUF", "CGEN", "LDO", "BIST", "CDS", "TRF", "TBB", "RFE", "RBB", "SX",
+        RxTSP, RxNCO, RxGFIR1, RxGFIR2, RxGFIR3a, RxGFIR3b, RxGFIR3c, LimeLight, LDO };
+    const char* moduleNames[] = { "AFE", "BIAS", "XBUF", "CGEN", "BIST", "CDS", "TRF", "TBB", "RFE", "RBB", "SX",
         "TxTSP", "TxNCO", "TxGFIR1", "TxGFIR2", "TxGFIR3a", "TxGFIR3b", "TxGFIR3c",
-        "RxTSP", "RxNCO", "RxGFIR1", "RxGFIR2", "RxGFIR3a", "RxGFIR3b", "RxGFIR3c", "LimeLight" };
+        "RxTSP", "RxNCO", "RxGFIR1", "RxGFIR2", "RxGFIR3a", "RxGFIR3b", "RxGFIR3c", "LimeLight", "LDO"};
 
     const uint16_t patterns[] = { 0xAAAA, 0x5555 };
     const uint8_t patternsCount = 2;
