@@ -235,6 +235,16 @@ public:
 
     //! Get the actual TX PAD gain in dB
     float_type GetTRFPAD_dB(void);
+    
+        /*!
+     * Set the TBB frontend gain in dB
+     * @param gain in dB relative to optimal gain (0 - optimal gain, >0 may cause saturation)
+     * @return 0 for success, else error
+     */
+    int SetTBBIAMP_dB(const float_type gain);
+
+    //! Get the TBB frontend gain in dB
+    float_type GetTBBIAMP_dB(void);
 
     /*!
      * Set the TX loopback PAD gain in dB
@@ -399,7 +409,7 @@ public:
     enum MemorySection
     {
         LimeLight = 0, EN_DIR, AFE, BIAS, XBUF, CGEN, LDO, BIST, CDS,
-        TRF, TBB, RFE, RBB, SX, TxTSP,
+        TRF, TBB, RFE, RBB, SX, TRX_GAIN, TxTSP,
         TxNCO, TxGFIR1, TxGFIR2, TxGFIR3a, TxGFIR3b, TxGFIR3c,
         RxTSP, RxNCO, RxGFIR1, RxGFIR2, RxGFIR3a, RxGFIR3b, RxGFIR3c,
         RSSI_DC_CALIBRATION, RSSI_PDET_TEMP_CONFIG, RSSI_DC_CONFIG,
