@@ -411,7 +411,7 @@ static const struct LMS7Parameter LMS7_ICT_LPFS5_F_TBB = { 0x0106, 14, 10, 12, "
 static const struct LMS7Parameter LMS7_ICT_LPFS5_PT_TBB = { 0x0106, 9, 5, 12, "ICT_LPFS5_PT_TBB", "This controls the operational amplifier's input stage bias current of the low band real pole filter of the transmitter's baseband" };
 static const struct LMS7Parameter LMS7_ICT_LPF_H_PT_TBB = { 0x0106, 4, 0, 12, "ICT_LPF_H_PT_TBB", "This controls the operational amplifiers input stage bias reference current of the high band low pass filter of the transmitter's baseband " };
 static const struct LMS7Parameter LMS7_ICT_LPFH_F_TBB = { 0x0107, 14, 10, 12, "ICT_LPFH_F_TBB", "controls the operational amplifiers output stage bias reference current of the high band low pass filter of the transmitter's baseband (LPFH_TBB)" };
-static const struct LMS7Parameter LMS7_ICT_LPFLAD_F_TBB = { 0x0107, 9, 5, 12, "ICT_LPFLAD_F_TBB", "This controls the operational amplfiers' output stages bias referene current of the low band ladder filter of the transmisster's baseband" };
+static const struct LMS7Parameter LMS7_ICT_LPFLAD_F_TBB = { 0x0107, 9, 5, 12, "ICT_LPFLAD_F_TBB", "This controls the operational amplfiers' output stages bias reference current of the low band ladder filter of the transmisster's baseband" };
 static const struct LMS7Parameter LMS7_ICT_LPFLAD_PT_TBB = { 0x0107, 4, 0, 12, "ICT_LPFLAD_PT_TBB", "This controls the operational amplifers' input stages bias reference current of the low band ladder filter of the transmitter's baseband" };
 static const struct LMS7Parameter LMS7_CG_IAMP_TBB = { 0x0108, 15, 10, 37, "CG_IAMP_TBB", "This controls the frontend gain of the TBB. For a given gain value, this control value varies with the set TX mode. After resistance calibration, the following table gives the nominal values for each frequency setting. However, this table is to be updated and corrected after calibration" };
 static const struct LMS7Parameter LMS7_ICT_IAMP_FRP_TBB = { 0x0108, 9, 5, 12, "ICT_IAMP_FRP_TBB", "This controls the reference bias current of the IAMP main bias current sources" };
@@ -448,7 +448,7 @@ static const struct LMS7Parameter LMS7_ICT_LNACMO_RFE = { 0x0110, 14, 10, 2, "IC
 static const struct LMS7Parameter LMS7_ICT_LNA_RFE = { 0x0110, 9, 5, 12, "ICT_LNA_RFE", "Controls the current of the LNA core" };
 static const struct LMS7Parameter LMS7_ICT_LODC_RFE = { 0x0110, 4, 0, 20, "ICT_LODC_RFE", "Controls the DC of the mixer LO signal at the gate of the mixer switches" };
 static const struct LMS7Parameter LMS7_CAP_RXMXO_RFE = { 0x0111, 9, 5, 4, "CAP_RXMXO_RFE", "Control the decoupling cap at the output of the RX Mixer" };
-static const struct LMS7Parameter LMS7_CGSIN_LNA_RFE = { 0x0111, 4, 0, 3, "CGSIN_LNA_RFE", "Controls the cap parallel with the LNA input input NMOS CGS to control the Q of the maching circuit and provides trade off between gain/NF and IIP. The higher the frequency, the lower CGSIN_LNA_RFE should be. Also, the higher CGSIN, the lower the Q, The lower the gain, the higher the NF, and the higher the IIP3" };
+static const struct LMS7Parameter LMS7_CGSIN_LNA_RFE = { 0x0111, 4, 0, 3, "CGSIN_LNA_RFE", "Controls the cap parallel with the LNA input input NMOS CGS to control the Q of the matching circuit and provides trade off between gain/NF and IIP. The higher the frequency, the lower CGSIN_LNA_RFE should be. Also, the higher CGSIN, the lower the Q, The lower the gain, the higher the NF, and the higher the IIP3" };
 static const struct LMS7Parameter LMS7_CCOMP_TIA_RFE = { 0x0112, 15, 12, 12, "CCOMP_TIA_RFE", "Compensation capacitor for TIA" };
 static const struct LMS7Parameter LMS7_CFB_TIA_RFE = { 0x0112, 11, 0, 230, "CFB_TIA_RFE", "Feeback capacitor for TIA. Controls the 3dB BW of the TIA. Should be set with calibration through digital baseband" };
 static const struct LMS7Parameter LMS7_G_LNA_RFE = { 0x0113, 9, 6, 15, "G_LNA_RFE", "Controls the gain of the LNA" };
@@ -640,8 +640,8 @@ static const struct LMS7Parameter LMS7_G_PGA_RBB_R3 = { 0x0126, 10, 6, 11, "G_PG
 static const struct LMS7Parameter LMS7_G_LNA_RFE_R3 = { 0x0126, 5, 2, 15, "G_LNA_RFE_R3", "[Alternative control] Controls the gain of the LNA"};
 static const struct LMS7Parameter LMS7_G_TIA_RFE_R3 = { 0x0126, 1, 0, 3, "G_TIA_RFE_R3", "[Alternative control] Controls the Gain of the TIA"};
 static const struct LMS7Parameter LMS7_RZ_CTRL = { 0x0122, 15, 14, 0, "RZ_CTRL", "Controls the PLL LPF zero resistor values"};
-static const struct LMS7Parameter LMS7_CMPLO_CTRL_SX = { 0x0122, 13, 13, 0, "CMPLO_CTRL_SX", "Controls the SXR/SXT PLL VCO comparator low treshold value"};
-static const struct LMS7Parameter LMS7_CMPLO_CTRL_CGEN_R3 = { 0x008B, 14, 14, 0, "CMPLO_CTRL_CGEN", "Controls the CGEN PLL VCO comparator low treshold value"};
+static const struct LMS7Parameter LMS7_CMPLO_CTRL_SX = { 0x0122, 13, 13, 0, "CMPLO_CTRL_SX", "Controls the SXR/SXT PLL VCO comparator low threshold value"};
+static const struct LMS7Parameter LMS7_CMPLO_CTRL_CGEN_R3 = { 0x008B, 14, 14, 0, "CMPLO_CTRL_CGEN", "Controls the CGEN PLL VCO comparator low threshold value"};
 static const struct LMS7Parameter LMS7_ISINK_SPIBUFF = { 0x00A6, 15, 13, 0, "ISINK_SPI_BUFF", "Controls the SPIBUF LDO output resistive load"};
 
 static const struct LMS7Parameter LMS7_DCMODE = { 0x05C0, 15, 15, 0, "DCMODE", "DC calibration mode" };
