@@ -8,6 +8,7 @@
 
 #define MCU_ID_DC_IQ_CALIBRATIONS 0x01
 #define MCU_ID_CALIBRATIONS_SINGLE_IMAGE 0x03
+#define MCU_ID_AGC_IMAGE 0x04
 
 #define MCU_FUNCTION_CALIBRATE_TX 1
 #define MCU_FUNCTION_CALIBRATE_RX 2
@@ -15,9 +16,11 @@
 #define MCU_FUNCTION_UPDATE_REF_CLK 4
 #define MCU_FUNCTION_TUNE_TX_FILTER 5
 #define MCU_FUNCTION_TUNE_RX_FILTER 6
+#define MCU_FUNCTION_AGC 254
 #define MCU_FUNCTION_GET_PROGRAM_ID 255
 
 LIME_API extern const uint8_t mcu_program_lms7_dc_iq_calibration_bin[16384];
+LIME_API extern const uint8_t mcu_program_lms7_agc_bin[16384];
 
 #endif
 
