@@ -16,6 +16,7 @@ using namespace std;
 #include <list>
 #include "ErrorReporting.h"
 #include "LMS7002M.h"
+#include "Logger.h"
 
 using namespace lime;
 
@@ -134,7 +135,7 @@ unsigned short MCU_BD:: mSPI_read(
     uint32_t rddata = 0;
     if(m_serPort->ReadLMS7002MSPI(&wrdata, &rddata, 1, mChipID)!=0)
         return 0;
-   
+
     return rddata & 0xFFFF;
 }
 
@@ -969,11 +970,6 @@ int MCU_BD::RunInstr_MCU(unsigned short * pPCVAL)
 	return retval;
 }
 
-void MCU_BD::Log(const char* msg)
-{
-    printf("%s", msg);
-}
-
 /** @brief Returns information about programming or reading data progress
 */
 MCU_BD::ProgressInfo MCU_BD::GetProgressInfo() const
@@ -1009,8 +1005,11 @@ void MCU_BD::RunProcedure(uint8_t id)
     mSPI_write(0x0000, id);
     uint8_t x0002reg = mSPI_read(0x0002);
     const uint8_t interupt6 = 0x08;
+    mSPI_write(0x0002, x0002reg & ~interupt6);
     mSPI_write(0x0002, x0002reg | interupt6);
     mSPI_write(0x0002, x0002reg & ~interupt6);
+    //MCU seems to be stuck at this point until any SPI operation is performed
+    mSPI_read(0x0002); //random spi action
     std::this_thread::sleep_for(std::chrono::microseconds(10));
 }
 
@@ -1033,7 +1032,7 @@ int MCU_BD::WaitForMCU(uint32_t timeout_ms)
     }while (std::chrono::duration_cast<std::chrono::milliseconds>(t2 - t1).count() < timeout_ms);
     mSPI_write(0x0006, 0); //return SPI control to PC
     //if((value & 0x7f) != 0)
-        std::printf("MCU algorithm time: %li ms\n", std::chrono::duration_cast<std::chrono::milliseconds>(t2 - t1).count());
+    lime::debug("MCU algorithm time: %li ms", std::chrono::duration_cast<std::chrono::milliseconds>(t2 - t1).count());
     return value & 0x7F;
 }
 
